      subroutine beh084(stkht,stkd,vexit,texit0,tsfc,psfc,zs,zm,
     &                  w,temp,press,nz,nstk,heff)
C
C     *** (c) Copr. 1992  Systems Applications, Inc.  San Rafael, CA
C
c*********************************************************************
c     Calculate plume rise using:
c      1) Neutral-Unstable plume rise equations of Briggs (1984)
c      2) Stable plume rise equations of Briggs (1975)
c   - This routine is based on a algorithm from TUPOS (Turner and 
c     Catalano, 1986, US EPA).
c   - Plume rise is adjusted due to stack tip downwash (Bjorklund and 
c     Bowers, 1982)
c   - Stable algorithm requires potential temperature lapse rate,
c     which is obtained from temp and press arrays, and is considered valid 
c     through an entire layer
c   - Temperature and winds are valid at layer interfaces
c
c   - THIS VERSION ADOPTED FOR UAM PTSRCE PREPROCESSOR: C Emery  Sep 1993
c
c     Inputs:
c       stkht      physical stack height (m)
c       stkd       stack diameter (m)
c       vexit      exit velocity (m/s)
c       texit0     exit temperature (K)
c       tsfc       surface temperature (K)
c       psfc       surface pressure (mb)
c       zs         layer interface height array (m)
c       zm         layer midpoint height array (m)
c       w          layer wind array (m/s)
c       temp       layer interface temperature array (K)
c       dthdz      layer potential temperature gradient array (K/m)
c       press      layer interface pressure array (mb)
c       nz         number of layers
c        
c     Internal Variables:
c       delh       final plume rise (m)
c       dwnwsh     stack tip downwash factor (0 to 1)
c       f0         bouancy flux out of stack (m4/s3)
c       fb         bouancy flux at bottom of a layer
c       fr         residual bouyancy flux at top of layer
c       flux       generic flux (one of the fluxes above)
c       froude     stack froude number
c       heff       final effective stack height (m)
c       nsteps     number of iterations to final plume rise
c       dpdz       vertical pressure gradient (mb/m)
c       tmp        ambient temperature (K)
c       dtdz       ambient potential temperature gradient (K/m)
c       wind       ambient windspeed (m/s) (minimum of 0.1 enforced)
c       zb         height of layer bottom (m)
c       zt         height of layer top (m)
c       kstk       layer index for stack
c
c       C Emery, SAI 10/91
c*********************************************************************

      real zs(nz), zm(nz), w(nz), press(nz), temp(nz)
      real dthdz(10)
      logical lprnt

      nsteps = 1
      delh = 0.
      g = 9.8
      gamma = 0.286
      dwnwsh = 1.
      lprnt = .false.
c     if (nstk.eq.1.or.nstk.eq.12.or.nstk.eq.25.or.nstk.eq.26
c    &    .or.nstk.eq.37.or.nstk.eq.50) lprnt = .true.

c-----Initialize potential temperature array 

      if (lprnt) then
      write(*,*)
      write(*,*)'*******************************'
      write(*,*)'STACK #: ',nstk
      write(*,*)'BEH084: tsfc,psfc ',tsfc,psfc
      write(*,*)'BEH084: zs,zm,w,press,temp,dthdz'
      endif
      do 5 k = 1,nz
         if (k.eq.1) then
           dz = zs(k)
           dthdz(k) = (1000.**gamma/dz)
     &                 *(temp(k)/press(k)**gamma
     &                 - tsfc/psfc**gamma)
         else 
           dz = zs(k) - zs(k-1)
           dthdz(k) = (1000.**gamma/dz)
     &              *(temp(k)/press(k)**gamma
     &              - temp(k-1)/press(k-1)**gamma)
         endif
         if (lprnt) 
     &      write(*,*) zs(k),zm(k),w(k),press(k),temp(k),dthdz(k)
   5  continue
         
c-----Determine layer index in which stack resides and initialize wind
c     and temp variables by interpolating

      do 10 k = 1,nz
         if (stkht.lt.zs(k)) then
            kstk = k
            goto 20
         endif
   10 continue
      goto 1000
   20 continue

      if ((kstk.eq.1 .and. stkht.le.zm(kstk)) .or.
     &    (kstk.eq.nz .and. stkht.gt.zm(kstk))) then
         wind = amax1(w(kstk),0.1)
         goto 25
      elseif (stkht.gt.zm(kstk)) then
         kp = kstk + 1
         km = kstk
      else
         kp = kstk
         km = kstk - 1
      endif
      d1 = zm(kp) - stkht
      d2 = stkht - zm(km)
      f1 = d1/(d1+d2)
      f2 = d2/(d1+d2)
      wind = f2*w(kp) + f1*w(km)
      wind = amax1(wind,0.1)

  25  continue
      d1 = zs(kstk) - stkht
      if (kstk.eq.1) then
         d2 = stkht
         f1 = d1/(d1+d2)
         f2 = d2/(d1+d2)
         tmp = f2*temp(kstk) + f1*tsfc
      else
         d2 = stkht - zs(kstk-1)
         f1 = d1/(d1+d2)
         f2 = d2/(d1+d2)
         tmp = f2*temp(kstk) + f1*temp(kstk-1)
      endif
      zt = zs(kstk) - stkht
      zb = 0.
      if (lprnt) write(*,*)'BEH084: stkht,kstk,w,temp,zt,zb == ',
     &                   stkht,kstk,wind,tmp,zt,zb
 
c-----Use stack temperature of at least .1 deg higher than ambient
c     (tcm, 10/21/91)
 
      texit = texit0
      if (texit0 .lt. tmp+.1) texit = tmp+.1

c-----Calculate Froude number and stack tip downwash correction factor

      froude = vexit**2./(g*stkd*(texit - tmp)/tmp)
      dwnwsh = 1.
      if (froude.ge.3.) then
         if (wind.ge.vexit) then
            dwnwsh = 0.
            goto 1000
         elseif ((wind.gt.vexit/1.5) .and. (wind.lt.vexit)) then
            dwnwsh = (3.*vexit - 3.*wind)/vexit
         endif
      endif

c-----Find Initial buoyancy flux and neutral-unstable momentum rise
      delhum = 3.*stkd*vexit/wind
      if (delhum .gt. zt) then
        do 50 kend=kstk+1,nz
          fcum = zt
          wcum = fcum*w(kstk)
          do 40 k=kstk+1,kend
            ff = amin1(delhum+stkht,zs(k))-zs(k-1)
            fcum = fcum + ff
            wcum = wcum + ff*w(k)
   40     continue
          wwav = amax1(wcum/fcum,0.1)
          delhum = 3.*stkd*vexit/wwav
          if (delhum .lt. zs(kend)-stkht) go to 55
   50   continue
      endif
   55 f0 = g*vexit*stkd**2.*(texit - tmp)/(4.*texit)
      flux = f0
      if (lprnt) then
      write(*,*) '--------------------------------------------'
      write(*,*) 'froude,dwnwsh,delhum ',froude,dwnwsh,delhum
      endif

c-----Loop by layer to find plume rise, initialize some variables

  100 continue
      if (nsteps.gt.1) then
         flux = fr
         d1 = zm(kstk) - zs(kstk-1)
         d2 = zs(kstk-1) - zm(kstk-1)
         f1 = d1/(d1+d2)
         f2 = d2/(d1+d2)
         wind = f2*w(kstk) + f1*w(kstk-1)
         wind = amax1(wind,0.1)
         tmp = temp(kstk-1)
         zt = zs(kstk) - stkht
         zb = zs(kstk-1) - stkht
      endif
      dtdz = dthdz(kstk)
      if (lprnt) then
      write(*,*)'flux,wind,temp,zt,zb,kstk,dtdz '
      write(*,*)flux,wind,tmp,zt,zb,kstk,dtdz
      endif
      if (dtdz.lt.0.001) goto 200 
      if (dtdz.ge.0.001) goto 300

c---------------------------------------------------------------------
c-----Neutral-unstable case

  200 continue

c-----Neutral-unstable bouyancy rise

      if (lprnt) write(*,*) '*****Unstable case*****'
      delhub1 = 30.*(flux/wind)**0.6 + zb
      delhub2 = 24.*(flux/wind**3.)**0.6
     &          *(stkht + 200.*(flux/wind**3.))**0.4 + zb
      delhub = amin1(delhub1,delhub2)
      if (delhub.eq.delhub1) iub = 1
      if (delhub.eq.delhub2) iub = 2
      if (lprnt) write(*,*)'delhub',delhub

c-----Neutral-unstable rise is maximum of momentum and buoyancy rise

      if ((nsteps.eq.1).and.(delhum.gt.delhub)) then
         if (lprnt) write(*,*)'using delhum'
         delh = delhum
         goto 1000
      endif
      if (lprnt) write(*,*)'using delhub'
      delh = delhub
      if (delh.lt.zt) goto 1000

c-----Calculate residual buoyancy if plume rise is beyond layer containing
c     stack

      if (lprnt) write(*,*)'calculating fr'
      if (iub.eq.1) fr = wind*((delh - zt)/30.)**(5./3.)
      if (iub.eq.2) fr = 5.5e-3*(delh - zt)*wind**3./
     &                   (1. + stkht/(delh-zt))**(2./3.)
      if (lprnt) write(*,*)'fr iub',fr,iub
      if(fr.le.0.) goto 1000
      nsteps = nsteps + 1
      kstk = kstk + 1
      if(kstk.gt.nz) goto 1000
      if (lprnt) write(*,*)'nsteps',nsteps
      goto 100

c----------------------------------------------------------------------
c-----Stable case

  300 continue

      if (lprnt) write(*,*)'*****Stable case****'
c-----Determine stable momentum rise (use minimum of stable and neutral-
c     unstable momentum rise as momentum rise in stable conditions)

      delhsm = 0.646*(vexit**2.*stkd**2./(texit*wind))**(1./3.)
     &         *tmp**0.5/(dtdz**(1./6.))
      delhsm = amin1(delhsm,delhum)
      if (lprnt) write(*,*)'delhsm',delhsm

c-----Stable buoyancy rise

      delhsb1 = (1.8*flux*tmp/(wind*dtdz) + zb**3.)**(1./3.)
      delhsb2 = (4.1*flux*tmp/(f0**(1./3.)*dtdz)
     &          + zb**(8./3.))**(3./8.)
      delhsb = amin1(delhsb1,delhsb2)
      if (delhsb.eq.delhsb1) isb = 1
      if (delhsb.eq.delhsb2) isb = 2
      if (lprnt) write(*,*)'delhsb',delhsb

c-----Stable plume rise is maximum between stable momentum rise and 2/3
c     stable bouyancy rise of top of plume

      if ((nsteps.eq.1).and.(delhsm.gt.(2.*delhsb/3.))) then
         delh = delhsm
         if (lprnt) write(*,*)'using delhsm'
         goto 1000
      endif
      if (lprnt) write(*,*)'using delhsb'
      delh = delhsb
      if (delh.lt.zt) then
         delh = 2.*delh/3.
         goto 1000
      endif

c-----Calculate residual buoyancy if top of plume is beyond layer containing
c     stack

      if (lprnt) write(*,*)'calculating fr'
      if (nsteps.eq.1) then
         fb = f0
      else
         fb = fr
      endif
      if (isb.eq.1) fr = fb - (0.56*dtdz*wind/tmp)
     &                   *(zt**3. - zb**3.) 
      if (isb.eq.2) fr = fb - (0.24*dtdz*f0**(1./3.)/tmp)
     &                   *(zt**(8./3.) - zb**(8./3.))
      if (fr.le.0.) then
         delh = 2.*delh/3.
         goto 1000
      endif
      nsteps = nsteps + 1
      kstk = kstk + 1
      if (kstk.gt.nz) then
         delh = 2.*delh/3.
         goto 1000
      endif
      if (lprnt) write(*,*)'fr,nsteps',fr,nsteps
      goto 100

c-----Final plume rise

 1000 heff = stkht + dwnwsh*delh 
c     if (heff.gt.zs(nz)) then
c        write(*,*)
c        write(*,*)'Warning: plume rise above region top!'
c        write(*,*)'Setting final effective height to just below RT'
c        write(*,*)
c        heff = zs(nz) - 10.
c     endif
      if (lprnt) write(*,*)'Exiting beh084'
      call flush(6)
      return
      end
