      SUBROUTINE PLMRIS (IPRINT,NAMLEN,TGRADB,TGRADA,ATPRES,
     $  STKHGT, STKDIA, STKTMP, STKVEL, FLWRAT, DIFBRK, TEMPER, UVECTR,
     $  VVECTR, RMISSV, MVARBL, MPTSRC, PLMHGT, JFLAG)
      SAVE
C
C NAME -- POINT SOURCE PLUME RISE
C
C DESCRIPTION -- CALCULATES EFFECTIVE PLUME HEIGHT FROM A POINT SOURCE
C                USING BRIGGS FORMULAE
C
C PROGRAMMER -- J AMES/SAI
C
C MODIFIER -- D.C. WHITNEY / SAI OCTOBER 1977
C          -- P.D. ALLEN   / ARB OCTOBER 1986
C
C
C
C INPUTS --
C         IPRINT    I  OUTPUT UNIT
C         NAMLEN    I  NAME LENGTH
C         SMOLWT    R  MOLECULAR WEIGHT
C         TGRADB    R  TEMPERATURE GRADIENT BELOW DIFFUSION BREAK
C         TGRADA    R  TEMPERATURE GRADIENT ABOVE DIFFUSION BREAK
C         ATPRES    R  ATMOSPHERIC PRESSURE
C         STKHGT    R  STACK HEIGHT
C         STKDIA    R  STACK DIAMETER
C         STKTMP    R  STACK EXIT TEMPERATURE
C         STKVEL    R  STACK EXIT VELOCITY
C         DIFBRK    R  DIFFUSION BREAK HEIGHT
C         TEMPER    R  GROUND-LEVEL TEMPERATURE
C         UVECTR    R  GROUND-LEVEL WIND U-VECTOR
C         VVECTR    R  GROUND-LEVEL WIND V-VECTOR
C         RMISSV    R  MISSING VARIABLE VALUE
C         MVARBL    I  VARIABLE NAME
C         MPTSRC    I  POINT SOURCE NAME
C
C OUTPUTS --
C         PLMHGT    R  HEIGHT OF PLUME (METERS)
C         JFLAG     I  COMPLETION FLAG
C
C LOCAL VARIABLES --
C         CP        R  HEAT CAPACITY OF DRY AIR AT CONSTANT PRESSURE
C                        (CAL/(GRAM-DEGREE K))
C         DELHP     R  HEIGHT OF PLUME ABOVE STACK (FEET)
C         DENS      R  DENSITY OF AIR AT STACK TEMPERATURE AND CURRENT
C                        PRESSURE (GRAMS PER CUBIC METER)
C         DENSTY    R  DENSITY OF AIR AT STP (GRAMS PER CUBIC METER)
C         DHP       R  INTERMEDIATE VALUE OF DELHP (FEET)
C         DTHDZ     R  DERIVATIVE OF POTENTIAL TEMPERATURE W.R.TRUE.
C                        HEIGHT(DEGREES R PER FOOT)
C         G         R  ACCELERATION DUE TO GRAVITY (FEET PER SECOND**2)
C         HI        R  HEIGHT OF INVERSION (FEET)
C         HS        R  STACK HEIGHT (FEET)
C         HTFLUX    R  HEAT FLUX (CAL PER HOUR)
C         PLHT      R  PLUME HEIGHT (FEET)
C         Q         HEAT FLUX (MEGAWATTS)
C         S         R  STABILITY PARAMETER (SEC**-2)
C         T         R  TEMPERATURE IN DEGREES RANKIN
C         TGRADI    R  TEMPERATURE GRADIENT ABOVE INVERSION
C                        (DEGREES R PER FOOT)
C         TGRADM    R  TEMPERATURE GRADIENT BELOW INVERSION
C                        (DEGREES R PER FOOT)
C         THETAP    R  POTENTIAL TEMPERATURE EXCESS OF PLUME
C         THP       R  INTERMEDIATE VALUE OF THETAP
C         TI        R  TEMPERATURE AT INVERSION (DEGREES R)
C         U         R  WIND SPEED (FEET PER SECOND)
C         XQ        R  BRANCH VALUE FOR Q (MEGAWATTS)
C         XS        R  BRANCH VALUE FOR S (SEC**-2)
C         XU        R  BRANCH VALUE FOR U (FEET PER SECOND)
C         XSTAR     R  SHORT FOR Q**(2/5) * HS**(3/5)
C         LDEBUG    L  FLAG TO WRITE DEBUG INFORMATION
C
C ROUTINES CALLED -- NONE
C
C ERROR CONDITIONS -- NONE
C
C OTHER INFORMATION --
C
C         REFERENCE -- BRIGGS, G. A. , \PLUME RISE PREDICTIONS\,
C         CHAPTER 3 OF \LECTURES ON AIR POLLUTION AND ENVIRONMENTAL
C         IMPACT ANALYSES , SPONSORED BY THE AMERICAN METEOROLOGICAL
C         SOCIETY, BOSTON, MASS., (DUANE HAUGEN, WORKSHOP COORDINATOR),
C         29 SEPTEMBER - 3 OCTOBER 1975.
C
C
C SET DIMENSIONS OF NAMES
C
      DIMENSION MVARBL(NAMLEN)
      DIMENSION MPTSRC(NAMLEN)
      LOGICAL LDEBUG
C
C DECLARE CONSTANTS
C
      DATA G /32.2/
      DATA XS /0.0/
      DATA XU /1.64/
      DATA XQ /20.0/
      DATA CP /0.24/
      DATA DENSTY /1293./
C
C
C   SET DEBUG FLAG
C
      LDEBUG = .FALSE.
      INQUIRE (FILE='P$DEBUG',EXIST=LDEBUG)
C
C CALCULATE FLOW RATE, DENSITY, AND HEAT FLUX
C
C THE FOLLOWING LINE CHANGED TO ASSUME ACTUAL FLOWRATE AS INPUT
C P. ALLEN 10/28/86
C     DENS = DENSTY
      DENS=DENSTY * 273./STKTMP * ATPRES
C
C IF USING VELOCITY TO CALCULATE FLOWRATE, CORRECT DENSITY
C FOR TEMPERATURE AND PRESSURE
C THE FOLLOWING THREE LINES CHANGED TO CAPTURE ZERO FLOWRATES
C P. ALLEN 10/28/86
C     IF (FLWRAT .EQ. RMISSV) DENS = DENSTY * 273./STKTMP * ATPRES
C     IF (FLWRAT .EQ. RMISSV) FLWRAT = STKVEL * 3.1415927 / 4.0 *
C    $                        STKDIA ** 2
      IF (FLWRAT .LE. 0.0) DENS = DENSTY * 273./STKTMP * ATPRES
      IF (FLWRAT .LE. 0.0) FLWRAT = STKVEL * 3.1415927 / 4.0 *
     $                        STKDIA ** 2
      HTFLUX = FLWRAT * CP * DENS* (STKTMP - TEMPER)
      IF (HTFLUX .LT. 0.) HTFLUX = 0.
C
C CONVERT EVERY INPUT TO ENGINEERING UNITS
C
      Q = 1.16E-9 * HTFLUX
      HS = 3.2808 * STKHGT
      U = 0.0009113 * SQRT(UVECTR ** 2 + VVECTR **2)
      T  = 1.8    * TEMPER
      HI = 3.2808 * DIFBRK
      TGRADM = 0.5486 * TGRADB
      TGRADI = 0.5486 * TGRADA
C
C SET THE COMPLETION FLAG
C
      JFLAG = 0
C***********************************************************************
C
C     *** WHERE IS STACK IN RELATION TO INVERSION BASE
C
      HTABV = 1.E10
      IPUNCH = 0
      IF ( HS .GT. HI) GO TO 400
C***********************************************************************
C
C     *** STACK IS BELOW INVERSION
C
      DELHP = 1.E+10
C
      DTHDZ = TGRADM + .0054
      S = G / T * DTHDZ
      IF (S .LE. XS) GO TO 145
      IF (U .LE. 0.) GO TO 140
C
C          FORMULA (3)
      DELHP = 29.26 * (Q / U / S) ** .333333
      DH1 = DELHP
C  A DEBUG WRITE
      if (ldebug) then
      WRITE(6,2700) Q, U, S, DELHP
 2700 FORMAT(1X,'NOW USING FORMULA 3 ',/,1X,'Q = ', F14.3, /,
     $       1X, 'U = ', F14.3, /, 1X, 'S = ', F14.3,
     $       /, 1X, 'DELHP = ', F14.3)
      endif
      IF (U .GE. XU) GO TO 145
C
C          FORMULA (4)
  140 DHP = 28.31 * Q ** .25 / S ** .375
C  A DEBUG WRITE
      if (ldebug) then
      WRITE(6,2701) Q, U, S, DHP
 2701 FORMAT(1X,'NOW USING FORMULA 4 ',/,1X,'Q = ', F14.3, /,
     $       1X, 'U = ', F14.3, /, 1X, 'S = ', F14.3,
     $       /, 1X, 'DHP = ', F14.3)
      endif
      DELHP = AMIN1 (DELHP, DHP)
      DH1 = DELHP
C
C
  145 IF (Q .LT. XQ) GO TO 160
C
C          FORMULA (5)
      DELHP = 74.9 * Q ** .33333 * HS ** .666667 / U
C  A DEBUG WRITE
      if (ldebug) then
      WRITE(6,2702) Q, U, HS, DELHP
 2702 FORMAT(1X,'NOW USING FORMULA 5 ',/,1X,'Q = ', F14.3, /,
     $       1X, 'U = ', F14.3, /, 1X, 'HS = ', F14.3,
     $       /, 1X, 'DELHP = ', F14.3)
      endif
      GO TO 200
C
C          FORMULA (6)
  160 XSTAR = Q ** .4 * HS ** .6
      DELHP = 137.9 * (Q * XSTAR * XSTAR) ** .333333 / U
C  A DEBUG WRITE
      if (ldebug) then
      WRITE(6,2703) Q, U, HS, DELHP
 2703 FORMAT(1X,'NOW USING FORMULA 6 ',/,1X,'Q = ', F14.3, /,
     $       1X, 'U = ', F14.3, /, 1X, 'HS = ', F14.3,
     $       /, 1X, 'DELHP = ', F14.3)
      endif
C
C     *** CALCULATE PREDICTED PLUME HEIGHT
C
  200 IF (S .GT. XS) DELHP = AMIN1(DELHP,DH1)
      PLHT = DELHP + HS
      DTHDZ = TGRADI + .0054
C
C     *** IF THIS IS BELOW THE INVERSION, WE ARE FINISHED
C
      IF  (PLHT .LT. HI .OR. DTHDZ .LE. 0.) GO TO 999
C
C     *** IF NOT, WE MUST FIND OUT HOW FAR IT PENETRATES THE INVERSION
C
      THETAP = 1.E10
      IF (U .LE. 0) GO TO 225
C
C          FORMULA (7)
      IF (HI .EQ. HS ) HI = HI - 2.
      THETAP = 4108.9 * T / G * Q / (U*(HI-HS)*(HI-HS))
C  A DEBUG WRITE
      if (ldebug) then
      WRITE(6,2704) Q, U, HS, THETAP, T, HI
 2704 FORMAT(1X,'NOW USING FORMULA 7 ',/,1X,'Q = ', F14.3, /,
     $       1X, 'U = ', F14.3, /, 1X, 'HS = ', F14.3,
     $       /, 1X, 'THETAP = ', F14.3,
     $       /, 1X, 'T = ', F14.3,
     $       /, 1X, 'HI = ', F14.3)
      endif
      IF (U .GE. XU) GO TO 250
C
C          FORMULA (8)
  225 THP = 1018.1 * T/G * Q**.666667 / HI**1.666667
C  A DEBUG WRITE
      if (ldebug) then
      WRITE(6,2705) Q, U, HS, THP, T, HI
 2705 FORMAT(1X,'NOW USING FORMULA 8 ',/,1X,'Q = ', F14.3, /,
     $       1X, 'U = ', F14.3, /, 1X, 'HS = ', F14.3,
     $       /, 1X, 'THP = ', F14.3,
     $       /, 1X, 'T = ', F14.3,
     $       /, 1X, 'HI = ', F14.3)
      endif
      THETAP = AMIN1 (THETAP, THP)
C
  250  HTABV = THETAP/DTHDZ + HI
      IPUNCH = 1
C  A DEBUG WRITE
      if (ldebug) then
      WRITE(6,2706) Q, DTHDZ, HI, HTABV
 2706 FORMAT(1X,'NOW USING FORMULA $250 ',/,1X,'Q = ', F14.3, /,
     $       1X, 'DTHDZ = ', F14.3, /, 1X, 'HI = ', F14.3,
     $       /, 1X, 'HTABV = ', F14.3)
      endif
C     NOW CALCULATE PLUME RISE AS IF STACK WAS ABOVE THE INVERSION BASE
C***********************************************************************
C
C     *** IF THE STACK IS ABOVE THE INVERSION BASE
C
  400 DTHDZ = TGRADI + .0054
      TI = T + TGRADM * HI
      S = G / TI * DTHDZ
      IF (S .LE. XS) GO TO 460
      DELHP = 1.E10
      IF (U .LE. 0) GO TO 440
C
C          FORMULA (3)
      DELHP = 29.26 * (Q/U/S) ** .333333
      DH1 = DELHP
C  A DEBUG WRITE
      if (ldebug) then
      WRITE(6,2707) Q, U, S, DELHP
 2707 FORMAT(1X,'NOW USING FORMULA 3.2 ',/,1X,'Q = ', F14.3, /,
     $       1X, 'U = ', F14.3, /, 1X, 'S = ', F14.3,
     $       /, 1X, 'DELHP = ', F14.3)
      endif
      IF (U .GE. XU) GO TO 460
C
C          FORMULA (4)
  440 DHP = 28.31 * Q**.25 / S**.375
C  A DEBUG WRITE
      if (ldebug) then
      WRITE(6,2708) Q, U, S, DHP
 2708 FORMAT(1X,'NOW USING FORMULA 4.2 ',/,1X,'Q = ', F14.3, /,
     $       1X, 'U = ', F14.3, /, 1X, 'S = ', F14.3,
     $       /, 1X, 'DHP = ', F14.3)
      endif
      DELHP = AMIN1 (DELHP, DHP)
      DH1 = DELHP
C
C     ** IF THE STACK IS ABOVE THE SURFACE INVERSION
C
  460 IF (Q .LT. XQ)  GO TO 480
      DELHP = 74.9 * Q **.333333 * HS**.666667 / U
      if (ldebug) then
      WRITE(6,2709) Q, U, HS, DELHP
 2709 FORMAT(1X,'NOW USING FORMULA at 460 ',/,1X,'Q = ', F14.3, /,
     $       1X, 'U = ', F14.3, /, 1X, 'HS = ', F14.3,
     $       /, 1X, 'DELHP = ', F14.3)
      endif
      GO TO 500
  480 XSTAR = Q ** .4 * HS ** .6
      DELHP = 137.9 * (Q*XSTAR*XSTAR) ** .333333 / U
      if (ldebug) then
      WRITE(6,2710) Q, U, XSTAR, DELHP
 2710 FORMAT(1X,'NOW USING FORMULA at 480 ',/,1X,'Q = ', F14.3, /,
     $       1X, 'U = ', F14.3, /, 1X, 'XSTAR = ', F14.3,
     $       /, 1X, 'DELHP = ', F14.3)
      endif
C
  500 IF (S .GT. XS) DELHP = AMIN1(DELHP,DH1)
      PLHT = DELHP + HS
      if (ldebug) then
      WRITE(6,2711) S, DH1, DELHP, HS, PLHT
 2711 FORMAT(1X,'NOW USING FORMULA at 480 ',/,1X,'S = ', F14.3, /,
     $       1X, 'DH1 = ', F14.3, /, 1X, 'DELHP = ', F14.3,
     $       /, 1X, 'HS = ', F14.3, /,1X, 'PLHT = ', F14.3)
      endif
      IF (IPUNCH .NE. 1) GO TO 999
      PLHT = DELHP + HI
      PLHT = AMIN1(PLHT,HTABV)
      if (ldebug) then
      WRITE(6,2712) HTABV, DELHP, HI, PLHT
 2712 FORMAT(1X,'NOW USING FORMULA at 480 ', /,
     $       1X, 'HTABV = ', F14.3, /, 1X, 'DELHP = ', F14.3,
     $       /, 1X, 'HI = ', F14.3, /,1X, 'PLHT = ', F14.3)
      endif
      GO TO 999
C
C
  999 PLMHGT = 0.3048 * PLHT
      RETURN
      END
